{% extends fobi_theme.base_edit_template %}

{% load i18n %}

{% block page-title %}{% trans "Edit form entry" %}{% endblock page-title %}

{% block navbar-menu-content %}
<li class="active"><a href="{% url 'fobi.edit_form_entry' form_entry.pk %}">{% trans "Edit" %}</a></li>
<li><a href="{% url 'fobi.view_form_entry' form_entry.slug %}">{% trans "View" %}</a></li>
{% comment %}
<li class="dropdown">
  <a class="dropdown-toggle" data-toggle="dropdown" href="#">
  {% trans "Your forms" %} <span class="caret"></span>
  </a>
  <ul class="dropdown-menu">
    {% for entry in all_form_entries %}
    <li>
      <a href="{% url 'fobi.edit_form_entry' entry.pk %}">{{ entry.name }}</a>
    </li>
    {% endfor %}
  </ul>
</li>
{% endcomment %}
{% endblock navbar-menu-content %}

{% block main-content-inner-attrs %}{% endblock main-content-inner-attrs %}

{% block content-wrapper %}
    {% include fobi_theme.edit_form_entry_ajax_template %}
{% endblock content-wrapper %}

{% block sidebar-wrapper %}
{% endblock sidebar-wrapper %}
