{% extends "fobi/generic/snippets/form_ajax.html" %}

{% block form_page_header_html_class %}page-header{% endblock %}

{% block form_html_class %}form-horizontal{% endblock %}

{% block form_button_outer_wrapper_html_class %}control-group{% endblock %}

{% block form_button_wrapper_html_class %}controls{% endblock %}

{% block form_primary_button_html_class %}btn btn-primary{% endblock %}
