__title__ = 'fobi.tests.constants'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'FOBI_TEST_USER_USERNAME', 'FOBI_TEST_USER_PASSWORD',
    'TEST_FORM_NAME', 'TEST_FORM_SLUG'
)

FOBI_TEST_USER_USERNAME = 'test_admin'
FOBI_TEST_USER_PASSWORD = 'test'
TEST_FORM_NAME = 'Test form'
TEST_FORM_SLUG = 'test-form'